@@ -13,7 +13,7 @@
  *
  * Filter Options
  * --------------
- *  block_size (option slot 0) : interger (optional)
+ *  block_size (option slot 0) : integer (optional)
  *      What block size to use (in elements not bytes). Default is 0,
  *      for which bitshuffle will pick a block size with a target of 8kb.
  *  Compression (option slot 1) : 0 or BSHUF_H5_COMPRESS_LZ4
@@ -32,6 +32,10 @@
 #ifndef BSHUF_H5FILTER_H
 #define BSHUF_H5FILTER_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #define H5Z_class_t_vers 2
 #include "hdf5.h"
 
@@ -40,6 +44,7 @@
 
 
 #define BSHUF_H5_COMPRESS_LZ4 2
+#define BSHUF_H5_COMPRESS_ZSTD 3
 
 
 extern H5Z_class_t bshuf_H5Filter[1];
@@ -55,5 +60,8 @@ extern H5Z_class_t bshuf_H5Filter[1];
  */
 int bshuf_register_h5filter(void);
 
+#ifdef __cplusplus
+} // extern "C"
+#endif
 
 #endif // BSHUF_H5FILTER_H
